module Totter
  class Client
    # Client methods for working with activities in the application.
    module Activities
      # Default query parameters for retrieving activities
      DEFAULT_ACTIVITY_OPTIONS = {
        :limit => 1000,
        :offset => 0
      }

      # Returns a user's activities
      #
      # @param user_id [Numeric] The user's id
      # @param options [Hash] Parameters for returning selected activities
      # @return [Hashie::Mash]
      # @example
      #   Totter.activity(1)
      def activities(user_id, options = DEFAULT_ACTIVITY_OPTIONS)
        get("users/#{user_id}/activities?limit=#{options[:limit]}&offset=#{options[:offset]}").body
      end

      # Returns activities performed on a given user
      #
      # @param user_id [Numeric] The user's id
      # @param options [Hash] Parameters for returning selected activities
      # @return [Hashie::Mash]
      # @example
      #   Totter.activity(1)
      def my_activities(options = DEFAULT_ACTIVITY_OPTIONS)
        get("me/activities?limit=#{options[:limit]}&offset=#{options[:offset]}").body
      end

      # Returns activities performed by a user's friends
      #
      # @param user_id [Numeric] The user's id
      # @param options [Hash] Parameters for returning selected activities
      # @return [Hashie::Mash]
      # @example
      #   Totter.activity(1)
      def friends_activities(options = DEFAULT_ACTIVITY_OPTIONS)
        get("me/activities/friends?limit=#{options[:limit]}&offset=#{options[:offset]}").body
      end

    end
  end
end
