module Totter
  class Client
    # Client methods for working with avatars.
    module Comments
      # Gets comments for a given decision
      #
      # @param user_id [Numeric] The decision's user id
      # @param decision_id [Numeric] The decision's id
      # @return [Array]
      # @example
      #   Totter.comments(1, 1)
      def comments(user_id, decision_id)
        get("users/#{user_id}/decisions/#{decision_id}/comments").body
      end

      # Creates a new comment
      #
      # @param user_id [Numeric] The decision's user id
      # @param decision_id [Numeric] The decision's id
      # @param message [String] The comment body
      # @return [Hashie::Mash]
      # @example
      #   Totter.create_comment(1, 1, 'I love boots!')
      def create_comment(user_id, decision_id, message)
        options = {
          :comment => {
            :message => message
          }
        }
        post("users/#{user_id}/decisions/#{decision_id}/comments", options).body
      end

      # Destroys a comment
      #
      # @param user_id [Numeric] The decision's user id
      # @param decision_id [Numeric] The decision's id
      # @param comment_id [Numeric] The comment id
      # @return [Boolean]
      # @example
      #   Totter.destroy_comment(1, 1, 15)
      def destroy_comment(user_id, decision_id, comment_id)
        boolean_from_response(:delete, "users/#{user_id}/decisions/#{decision_id}/comments/#{comment_id}")
      end

    end
  end
end
