module Totter
  class Client
    # Client methods for working with stickers.
    module Stickers
      # Get all of the users with a given sticker.
      #
      # @param sticker_name [String] the sticker to get users for
      # @return [Array] an array of `Hashie::Mash` objects representing users
      # @example
      #   Totter.sticker('staff')
      def sticker(sticker_name)
        get("stickers/#{sticker_name}").body
      end

      # Follow all users with a specific sticker
      #
      # Requires authenticated client.
      #
      # @param sticker [String] sticker to follow
      # @return [Boolean] True if follow was successful, false otherwise
      # @example
      #   client.follow_sticker('featured')
      def follow_sticker(sticker)
        boolean_from_response(:post, "stickers/#{sticker}/follow")
      end
    end
  end
end
